@@ -2,7 +2,7 @@ package Devel::Cover::Report::Coveralls;
 use strict;
 use warnings;
 use 5.008005;
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 our $CONFIG_FILE = '.coveralls.yml';
 our $API_ENDPOINT = 'https://coveralls.io/api/v1/jobs';
@@ -119,8 +119,10 @@ sub report {
     my $furl = Furl->new;
     my $response = $furl->post($API_ENDPOINT, [], [ json => encode_json $json ]);
 
-    my $res = decode_json($response->content);
-    if ($response->is_success) {
+    my $res = eval { decode_json($response->content); };
+    if ($@) {
+        print "error: " . $response->content;
+    } elsif ($response->is_success) {
         print "register: " . $res->{url} . "\n";
     } else {
         print "error: " . $res->{message} . "\n";
@@ -160,7 +162,7 @@ Devel::Cover::Report::Coveralls - coveralls backend for Devel::Cover
 
 =begin html
 
-<img src="http://media.tumblr.com/ec2a3b369f1380495512d827e9e8cfa1/tumblr_inline_mlc34k7g1a1qz4rgp.png" />
+<img src="http://kan.github.io/images/p5-ltsv.png" />
 
 =end html
 
